#: -*- coding: utf-8 -*-
"""
.. _Docutils Configuration: http://docutils.sourceforge.net/docs/user/config.html

App default settings
====================

Default settings rstviews needs. You can override them in your project
settings file.

"""  # noqa: E501
#: Some parse options you should not change.
#: They're automatically appended to each used parser options set.
RSTVIEW_PARSER_SECURITY = {
    'halt_level': 6,  # Dont halt script execution even if errors
    'enable_exit': 0  # Disable script exit when halt or finished
}

#: Default value for silent mode on parser
#:
#: Silent means errors and warnings are totally ignored in opposed to un-silent
#: where errors and warnings can be inserted into rendered source and also
#: push to standard output.
RSTVIEW_PARSER_SILENT = False

#: Locale code for document. Docutils parser don't support the
#: common pattern ``xx_XX``, only the first part ``xx``.
RSTVIEW_PARSER_LANGUAGE_CODE = "en"

#: The docutils writer to use, can be html4 (suitable for xhtml too) or html5.
RSTVIEW_PARSER_WRITER = "html5"

#: Enable unsafe file insertion directives, enable it at your own risk.
RSTVIEW_PARSER_ENABLE_FILE_INSERTION = False

#: Enable unsafe raw insertion directives, enable it at your own risk.
RSTVIEW_PARSER_ENABLE_RAW_INSERTION = False

#: Available parser options sets.
#:
#: These are options only for docutils parser, see `Docutils Configuration`_.
#:
#: Default entry ``default`` must allways be present.
RSTVIEW_PARSER_FILTER_SETTINGS = {
    'default': {
        'initial_header_level': 3,
        'file_insertion_enabled': RSTVIEW_PARSER_ENABLE_FILE_INSERTION,
        'raw_enabled': RSTVIEW_PARSER_ENABLE_RAW_INSERTION,
        'language_code': RSTVIEW_PARSER_LANGUAGE_CODE,
        'footnote_references': 'superscript',
        'doctitle_xform': False,
    },
}

#: CSS class prefix for generated Pygments elements when not using inline
#: styles.
RSTVIEW_PYGMENTS_CONTAINER_CLASSPREFIX = "pygments"

#: Enable usage of inline CSS styles in HTML generated by Pygments.
#:
#: This will fill your HTML with a lot of inline styles. Disabled by default,
#: the recommended way is to style it yourself, because there is not so much to
#: do once.
RSTVIEW_PYGMENTS_INLINESTYLES = False

#: Template string used to format error from
#: ``rst.viewreporter.SourceReporter``.
RSTVIEW_ERROR_TEMPLATE = u"Line {lineno} : {message}"
